package com.cirs.biz.service;

import java.util.List;
import com.cirs.biz.domain.TVerificationTask;

/**
 * 验证任务Service接口
 * 
 * @author allen
 * @date 2023-11-03
 */
public interface ITVerificationTaskService 
{
    /**
     * 查询验证任务
     * 
     * @param id 验证任务主键
     * @return 验证任务
     */
    public TVerificationTask selectTVerificationTaskById(Long id);

    /**
     * 查询验证任务列表
     * 
     * @param tVerificationTask 验证任务
     * @return 验证任务集合
     */
    public List<TVerificationTask> selectTVerificationTaskList(TVerificationTask tVerificationTask);

    /**
     * 新增验证任务
     * 
     * @param tVerificationTask 验证任务
     * @return 结果
     */
    public int insertTVerificationTask(TVerificationTask tVerificationTask);

    /**
     * 修改验证任务
     * 
     * @param tVerificationTask 验证任务
     * @return 结果
     */
    public int updateTVerificationTask(TVerificationTask tVerificationTask);

    /**
     * 批量删除验证任务
     * 
     * @param ids 需要删除的验证任务主键集合
     * @return 结果
     */
    public int deleteTVerificationTaskByIds(Long[] ids);

    /**
     * 删除验证任务信息
     * 
     * @param id 验证任务主键
     * @return 结果
     */
    public int deleteTVerificationTaskById(Long id);

    public String importTask(List<TVerificationTask> taskList, boolean updateSupport, String operName);

    public TVerificationTask getLastTask();
}
